@@ -11,6 +11,7 @@
 #' @param acc accumulator of the nodes already processed
 #' @return a matrix with the names of the nodes in the first row and their
 #' level on the second
+#' @keywords internal
 node_levels <- function(net, order, lvl = 1, acc = NULL){
   ret <- acc
   if(length(order) > 0){
@@ -23,19 +24,20 @@ node_levels <- function(net, order, lvl = 1, acc = NULL){
   return(ret)
 }
 
-#' Plots a Bayesian networks in a hierarchical way
+#' Plots a Bayesian network in a hierarchical way
 #'
-#' Calculates the levels of each node and then plots them in a hierarchical
-#' layout in visNetwork.
+#' This function calculates the levels of each node and then plots them in a hierarchical
+#' layout in visNetwork. Can be used in place of the generic plot function 
+#' offered by bnlearn for "bn" and "bn.fit" S3 objects.
 #' @param structure the structure or fit of the network.
 #' @importFrom magrittr "%>%"
 #' @examples 
 #' \donttest{
 #' dt_train <- dbnR::motor[200:2500]
 #' net <- bnlearn::mmhc(dt_train)
-#' plot_network(net)
-#' fit <- bnlearn::bn.fit(net, dt_train, method = "mle")
-#' plot_network(fit) # Works for both the structure and the fitted net
+#' plot_static_network(net)
+#' fit <- bnlearn::bn.fit(net, dt_train, method = "mle-g")
+#' plot_static_network(fit) # Works for both the structure and the fitted net
 #' }
 #' @export
 plot_static_network <- function(structure){
@@ -80,6 +82,7 @@ plot_static_network <- function(structure){
 #' @param prev the level of the previous node processed
 #' @param acc the accumulator of the index in the current sub successions
 #' @return the vector of sub successions in each level
+#' @keywords internal
 acc_successions <- function(nodes, res = NULL, prev = 0, acc = 0){
   if(length(nodes) == 0)
     return(res)
@@ -95,6 +98,7 @@ acc_successions <- function(nodes, res = NULL, prev = 0, acc = 0){
 #' time slice and then gives a topological ordering of them.
 #' @param structure the structure of the network.
 #' @return the ordered nodes of t_0
+#' @keywords internal
 dynamic_ordering <- function(structure){
 
   nodes_0 <- grep("t_0", bnlearn::node.ordering(structure), value = T)
@@ -118,6 +122,7 @@ dynamic_ordering <- function(structure){
 #' @param max number of time slices in the net
 #' @param i current slice being processed
 #' @return the extended names
+#' @keywords internal
 expand_time_nodes <- function(name, acc, max, i){
   if(i == max)
     return(acc)
@@ -134,10 +139,15 @@ expand_time_nodes <- function(name, acc, max, i){
 #' relative position of each node with respect to his equivalent in the first
 #' slice. The result is a net where each time slice is ordered and separated
 #' from one another, where the leftmost slice is the oldest and the rightmost
-#' represents the present time.
+#' represents the present time. This function is also called by the generic
+#' plot function of "dbn" and "dbn.fit" S3 objects.
 #' @param structure the structure or fit of the network.
 #' @param offset the blank space between time slices
 #' @param subset_nodes a vector containing the names of the subset of nodes to plot
+#' @param reverse reverse to the classic naming convention of the nodes. 
+#' The oldest time-slice will now be t_0 and the most recent one t_n. 
+#' Only for visualization purposes, the network is unmodified underneath. If
+#' using subset_nodes, remember that t_0 is now the oldest time-slice.
 #' @return the visualization of the DBN
 #' @examples 
 #' \donttest{
@@ -149,11 +159,15 @@ expand_time_nodes <- function(name, acc, max, i){
 #' @importFrom magrittr "%>%"
 #' @import data.table
 #' @export
-plot_dynamic_network <- function(structure, offset = 200, subset_nodes = NULL){
+plot_dynamic_network <- function(structure, offset = 200, subset_nodes = NULL, reverse = FALSE){
   check_opt_pkgs_available()
   initial_dbn_check(structure)
   numeric_arg_check(offset)
-
+  logical_arg_check(reverse)
+  
+  if(reverse)
+    structure <- bnlearn::rename.nodes(structure, reverse_names(names(structure$nodes), attr(structure, "size")))
+  
   # Static net positioning
   nodes_uniq <- dynamic_ordering(structure)
   levels <- node_levels(structure, nodes_uniq)
@@ -167,6 +181,8 @@ plot_dynamic_network <- function(structure, offset = 200, subset_nodes = NULL){
 
   # Relative position of the nodes
   nodes_uniq <- expand_time_nodes(nodes_uniq, nodes_uniq, ord, 1)
+  if(reverse)
+    nodes_uniq <- reverse_names(nodes_uniq, attr(structure, "size"))
   
   all_pos <- Reduce(function(acu, x){
     c(acu, (positions * 100 + x * 100 * max_consec + x * offset))}, 
@@ -214,17 +230,24 @@ plot_dynamic_network <- function(structure, offset = 200, subset_nodes = NULL){
   return(ret)
 }
 
-#' Plots a Bayesian networks or a dynamic Bayesian network
+#' Plots a dynamic Bayesian network
 #'
-#' Selects the appropriate function depending on the class of the object
-#' @param structure the structure or fit of the network.
+#' Generic method for plotting the "dbn" S3 objects. Calls 
+#' \code{\link{plot_dynamic_network}} underneath.
+#' @param x the structure of the network.
 #' @param ... additional parameters for the visualization of a DBN
 #' @export
-plot_network <- function(structure, ...){
-  initial_bn_or_dbn_check(structure)
-  
-  if(is_dbn_or_dbnfit(structure))
-    plot_dynamic_network(structure, ...)
-  else
-    plot_static_network(structure)
+plot.dbn <- function(x, ...){
+  plot_dynamic_network(x, ...)
+}
+
+#' Plots a fitted dynamic Bayesian network
+#'
+#' Generic method for plotting the "dbn.fit" S3 objects. Calls 
+#' \code{\link{plot_dynamic_network}} underneath.
+#' @param x the structure of the network.
+#' @param ... additional parameters for the visualization of a DBN
+#' @export
+plot.dbn.fit <- function(x, ...){
+  plot_dynamic_network(x, ...)
 }
