@@ -12,15 +12,18 @@ sd_error <- function(orig, pred){
 }
 
 print_metrics <- function(metrics, obj_vars){
-  print("The average MAE per execution is:", quote = FALSE)
-  sapply(obj_vars, function(x){print(paste0(x, ": ", round(metrics[x], 4)),
-                                     quote = FALSE)})
+  cat("The average MAE per execution is:", fill = T)
+  sapply(obj_vars, function(x){cat(paste0(x, ": ", round(metrics[x], 4)),
+                                   fill = T)})
 }
 
 plot_single_result <- function(dt, results, var){
-  plot(ts(dt[, .SD, .SDcols = var]))
-  invisible(sapply(1:max(results[get("exec")]), function(x){
-    lines(results[get("exec") == x, .SD, .SDcols = var], col = "red")}))
+  min_val <- min(c(dt[, get(var)], results[, get(var)]))
+  max_val <- max(c(dt[, get(var)], results[, get(var)]))
+  plot(ts(dt[, get(var)]), ylim = c(min_val, max_val), ylab = var)
+  idx <- "exec"
+  for(i in results[, unique(get(idx))])
+    lines(results[get(idx) == i, get(var)], col = "red")
 }
 
 plot_results <- function(dt, results, obj_vars){
@@ -35,7 +38,8 @@ plot_results <- function(dt, results, obj_vars){
 #' named vector is provided instead of a data.table, nothing will be done and
 #' the named vector will be returned.
 #' @param dt a 1 row data.table or a named vector
-#' @return a vector with the values and the variable names
+#' @return a named vector with the values and the variable names
+#' @keywords internal
 as_named_vector <- function(dt){
   if(is.data.frame(dt)){
     initial_onerow_dt_check(dt)
@@ -50,88 +54,6 @@ as_named_vector <- function(dt){
   return(res)
 }
 
-#' Reduce the frequency of the time series data in a data.table
-#' 
-#' In a time series dataset, there is a time difference between one row and the 
-#' next one. This function reduces the number of rows from its current frequency
-#' to the desired one. Instead of the frequency in Hz, the number of seconds
-#' between rows is asked (Hz = 1/s).
-#' @param dt the original data.table
-#' @param obj_freq the desired number of seconds between rows
-#' @param curr_freq the number of seconds between rows in the original dataset
-#' @param id_var optional variable that labels different time series in a dataset, to avoid averaging values from different processes
-#' @return the data.table with the desired frequency
-#' @import data.table
-#' @export
-reduce_freq <- function(dt, obj_freq, curr_freq, id_var = NULL){
-  initial_df_check(dt)
-  if(!is.data.table(dt))
-    dt <- as.data.table(dt)
-  numeric_arg_check(obj_freq, curr_freq)
-  null_or_character_arg_check(id_var)
-  
-  dt_res <- copy(dt)
-  obj_vars <- c("idx", id_var)
-  n_rows <- ceiling(obj_freq / curr_freq)
-  obj_rows <- seq(1, dim(dt_res)[1], n_rows)
-  idx_vec <- as.vector(sapply(obj_rows, function(x, times){rep(x,times)}, times=n_rows))[1:dim(dt_res)[1]]
-  dt_res[, "idx" := idx_vec]
-  dt_res <- dt_res[, lapply(.SD, mean), by=obj_vars]
-  dt_res[, "idx" := NULL]
-  
-  return(dt_res)
-}
-
-#' Filter the instances in a data.table that have values of different ids in each row
-#' 
-#' Given an id variable that labels the different instances of a time series
-#' inside a dataset, discard the rows that have values from more than 1 id.
-#' @param f_dt folded data.table
-#' @param size the size of the data.table
-#' @param id_var the variable that labels each individual instance of the time series
-#' @return the filtered dataset
-#' @export
-filter_same_cycle <- function(f_dt, size, id_var){
-  initial_folded_dt_check(f_dt)
-  initial_size_check(size)
-  character_arg_check(id_var)
-  
-  cond <- Reduce(function(acu, x){paste0(acu, " & ", id_var, "_t_0 == ", id_var, "_t_", x)}, 
-                 seq_len(size-2)+1, init = paste0(id_var, "_t_0 == ", id_var, "_t_1"))
-  
-  return(f_dt[eval(parse(text=cond))])
-}
-
-#' Fold a dataset to a certain size and avoid overlapping of different time-series
-#' 
-#' If the dataset that is going to be folded contains several different time-series 
-#' instances of the same process, folding it could introduce false rows with data
-#' from different time-series. Given an id variable that labels the different 
-#' instances of a time series inside a dataset and a desired size, this function 
-#' folds the dataset and avoids mixing data from different origins in the same instance.
-#' @param dt data.table to be folded
-#' @param size the size of the data.table
-#' @param id_var the variable that labels each individual instance of the time-series
-#' @param clear_id_var boolean that decides whether or not the id_var column is deleted 
-#' @return the filtered dataset
-#' @export
-filtered_fold_dt <- function(dt, size, id_var, clear_id_var = TRUE){
-  logical_arg_check(clear_id_var)
-  
-  f_dt <- fold_dt(dt, size) 
-  f_dt <- filter_same_cycle(f_dt, size, id_var)
-  del_vars <- names(f_dt)[grepl(id_var, names(f_dt))]
-  if(clear_id_var)
-    f_dt[, (del_vars) := NULL]
-  else{
-    old_col <- del_vars[1]
-    f_dt[, (del_vars[-1]) := NULL]
-    data.table::setnames(f_dt, old_col, id_var)
-  }
-  
-  return(f_dt)
-}
-
 #' One hot encoder for natural numbers without the 0.
 #' 
 #' Given a natural number, return the natural number equivalent to its
@@ -139,6 +61,7 @@ filtered_fold_dt <- function(dt, size, id_var, clear_id_var = TRUE){
 #' 
 #' @param nat the natural number to convert
 #' @return the converted number
+#' @keywords internal
 one_hot <- function(nat){
   return(2^(nat-1))
 }
@@ -154,6 +77,7 @@ one_hot <- function(nat){
 #' @param max the maximum value allowed to be sampled
 #' @return the sampled value
 #' @importFrom stats runif
+#' @keywords internal
 trunc_geom <- function(p, max){
   return(floor(log(1 - runif(1)*(1 - (1 - p)^max)) / log(1 - p)))
 }
@@ -165,6 +89,7 @@ trunc_geom <- function(p, max){
 #' @param n_arcs the total number of arcs 
 #' @param nodes the name of all the nodes in the network
 #' @return a bn object
+#' @keywords internal
 bn_translate_exp = function(ps, ordering_raw, n_arcs, nodes){
   arc_mat <- nat_cl_to_arc_matrix_cpp(ps, ordering_raw, n_arcs)
   
@@ -178,6 +103,7 @@ bn_translate_exp = function(ps, ordering_raw, n_arcs, nodes){
 #' Experimental function that recounts the number of arcs in the position
 #' @param ps a position vector of natural numbers
 #' @return the number of arcs
+#' @keywords internal
 recount_arcs_exp = function(ps){
   n_arcs <- 0
   
@@ -195,6 +121,7 @@ recount_arcs_exp = function(ps){
 #' @param ordering the names of the variables
 #' @param size the desired size of the dbn
 #' @return a dictionary with the variable names in t_0 and in all other time slices
+#' @keywords internal
 nodes_gen_exp <- function(ordering, size){
   res <- list(ordering_t_0 = NULL, nodes = NULL)
   
@@ -214,6 +141,7 @@ nodes_gen_exp <- function(ordering, size){
 #' vector with variables named "Xi", where i is a number in the interval [0,n-1]
 #' @param n the total number of variables desired
 #' @return a character vector with the variable names
+#' @keywords internal
 ordering_gen_exp <- function(n){
   res <- rep("", n)
   for(i in 1:n)
@@ -222,7 +150,7 @@ ordering_gen_exp <- function(n){
   return(res)
 }
 
-#' Experimental function that generates a random DBN and samples a dataset that defines it
+#' Generate a random DBN and a sampled dataset
 #' 
 #' This function generates both a random DBN and a dataset that can be used to 
 #' learn its structure from data. It's intended for experimental use.
@@ -235,7 +163,7 @@ ordering_gen_exp <- function(n){
 #' @param min_coef minimum coefficient allowed for the parent nodes
 #' @param max_coef maximum coefficient allowed for the parent nodes
 #' @param seed the seed of the experiment
-#' @return a dictionary with the original network structure and the sampled dataset
+#' @return a list with the original network structure and the sampled dataset
 #' @import data.table
 #' @export
 generate_random_network_exp <- function(n_vars, size, min_mu, max_mu,
@@ -306,3 +234,13 @@ calc_size <- function(fit){
   
   return(res)
 }
+
+# Reverses the naming convention of a vector of nodes. This function transforms 
+# t_0 into t_n , t_1 into t_n-1 and so on. 
+reverse_names <- function(old_names, size){
+  sapply(old_names, function(x){
+    elems <- strsplit(x, "_t_")[[1]]
+    elems[2] <- abs(size - 1 - as.numeric(elems[2]))
+    paste0(elems[1], "_t_", elems[2])
+  }, USE.NAMES = F)
+}
